==> gbsite-1.0.0.tar.gz: gbsite/htdocs/about/contactsend.php <==
<?

/**************************************************
Program name:		contact.php
Author:					Allen McGrath (allen@greatbridge.com)

Description:		Recieves posted information from
								contact.php and performs the following:
			
			1.  Error checks required values.------- DONE
			2.  Inserts info into FEEDBACK table.--- DONE
			3.  Retrieves EMAIL from STAFF table.--- DONE
			4.  Sends email to STAFF.EMAIL.----------DONE
			5.  Displays template page.--------------DONE
			
Create Date:		9/19/00 

Modified Date(s):	
**************************************************/
 
/******************************************
 SET THE WEB_PAGE AND RUN SITEINFO 
*******************************************/
	
  $web_page = "contextpage";
  include("site_info.php");
  $group_group_id = "contact";
/******************************************
  SET DO_DEBUG TO YES IF YOU WANT TO SEE DEBUGGING
	AND ANY OTHER NEEDED VARIABLES
******************************************/
  $do_debug = "no";
	$context_error;	


/******************************************
 ERROR CHECK REQUIRED VALUES
 START WITH EMAIL ADDRESS
******************************************/

if (empty($email)) {
	$context_error[] = "You must enter an email address.";
} 
elseif (!eregi("^[_\.0-9a-z-]+@([0-9a-z][-0-9a-z\.]+)\.([a-z]{2,3}$)", $email, $check)) { 
	$context_error[] = "Your email address does not appear to be in a correct format."; 
} 

if (count($context_error)) 
	$context = "There was a problem processing your information.  The specific problem(s) are listed below.";

/******************************************
if ($do_debug == "yes") {
echo "email " . $email ." check " . $check[1] . "<br>";
echo "here 0 " . $check[0] . "<br>" ;
echo "here 1 " . $check[1] . "<br>" ;
echo "here 2 " . $check[2] . "<br>" ;
echo "context " . $context_error[0];
}
******************************************/

/******************************************
 ERROR CHECK THE SUBJECT (CATEGORY)
******************************************/

if (empty($cat_id)) {
	$context_error[] = "Please choose a subject for your email.";
}


/******************************************
 ERROR CHECK THE COMMENTS (COMMENT)
******************************************/

if (trim(empty($comment))) {
	$context_error[] = "Please enter comments for your email.";
}


/******************************************
 ERROR CHECK IS COMPLETE.  IF THERE ARE NO
 ERRORS, THEN PROCEED WITH THE INSERT.  OTHERWISE
 DROP THE $CONTEXT AND $CONTEXT_ERRORS.
******************************************/

if ($context_error) {
	$error_count = count($context_error);
	include($page_template);

	return;
}


/******************************************
 INSERT THE INFORMATION INTO THE FEEDBACK TABLE
 BEFORE INSERTING, MAKE SURE THERE ISN'T ALREADY
 A RECORD PRESENT (DOUBLE-CLICK, BACK BUTTON, ETC.).
 IF THERE IS, UPDATE THAT RECORD INSTEAD.
******************************************/

	$chk_query = "SELECT FEEDBACK_ID " .
						 	 "FROM FEEDBACK WHERE FEEDBACK_ID = '$feedback_id'" ;

	$chk_result = pg_exec($conn,$chk_query);
  $chk_numrows = pg_numrows($chk_result);

if (!$chk_numrows) {

	$ins_query = "INSERT INTO FEEDBACK ( " .
		  				 "FEEDBACK_ID, CAT_ID, EMAIL, COMMENT, SENT_DATE) " .
							 "VALUES ('$feedback_id',$cat_id,'$email','$comment',now())";

	$ins_result = pg_exec($conn,$ins_query);					
}
else {

	$upd_query = "UPDATE FEEDBACK SET " .
							 "CAT_ID = $cat_id, " .
							 "EMAIL = '$email', " .
							 "COMMENT = '$comment' " .
							 "WHERE FEEDBACK_ID = '$feedback_id'";
							 "VALUES ('$feedback_id',$cat_id,'$comment,now())";

	$upd_result = pg_exec($conn,$upd_query);	  
}

/******************************************
 GET THE RECIPIENT(S) TO RECEIVE THE EMAIL,
 DEFAULT IS WEBMASTER
******************************************/
	$em_query = "SELECT A.EMAIL, C.CAT_NAME FROM STAFF A, STAFF_EMAIL B, CATEGORY C " .
						"WHERE B.CAT_ID = $cat_id " .
						"AND C.CAT_ID = $cat_id " .
						"AND A.STAFF_ID = B.STAFF_ID " .
						"AND C.GROUP_ID = $site_group_id ";
	
	$em_result = pg_exec($conn,$em_query);

	
	$r = 0;
	
	while ($row = @pg_fetch_array($em_result,$r++)) {
		$em_to[$row["email"]] = $row["email"];
		list($to_key,$to_value) = each($em_to);
		
		if ($r == 1) {
		$em_subj[$row["subj"]] = $row["cat_name"];
		list($subj_key,$subj_value) = each($em_subj);
		}
	
/******************************************
 INSERT THE MAIL CLASS HERE.  NOT SURE IF
 WE ARE GOING TO USE THE SMTP SERVER, OR
 LOCAL MAIL.  ONCE THIS IS RESOLVED, PUT IT
 HERE
 
*******************************************/
		if ($do_debug == "yes") {
			echo "Mail to: " . $to_value . "<br>";
			echo "From: " . $email . "<br>";
			echo "Subj: " . $subj_value . "<br>";
			echo "Text: " . $comment . "<p>";
		}
		mail("$to_value","Message from website regarding $subj_value","$comment","From:$email");
	}		 
			 
/******************************************
EVERYTHING IS FINISHED SO INCLUDE THE TEMPLATE
******************************************/
		$context = "Thank you for your comments.  We will respond to your e-mail as quickly as possible.";
    include($page_template);
 ?>

==> gbsite-1.1.1.tar.gz: gbsite/htdocs/about/contactsend.php <==
<?

/**************************************************
Program name:		contact.php
Author:					Allen McGrath (allen@greatbridge.com)

Description:		Recieves posted information from
								contact.php and performs the following:
			
			1.  Error checks required values.------- DONE
			2.  Inserts info into FEEDBACK table.--- DONE
			3.  Retrieves EMAIL from STAFF table.--- DONE
			4.  Sends email to STAFF.EMAIL.----------DONE
			5.  Displays template page.--------------DONE
			
Create Date:		9/19/00 

Modified Date(s):	
**************************************************/
 
/******************************************
 SET THE WEB_PAGE AND RUN SITEINFO 
*******************************************/
	
  $web_page = "contextpage";
  include("site_info.php");
  $group_group_id = "about";
/******************************************
  SET DO_DEBUG TO YES IF YOU WANT TO SEE DEBUGGING
	AND ANY OTHER NEEDED VARIABLES
******************************************/
  $do_debug = "no";
	$context_error;	


/******************************************
 ERROR CHECK REQUIRED VALUES
 START WITH EMAIL ADDRESS
******************************************/

if (empty($email)) {
	$context_error[] = "You must enter an email address.";
} 
elseif (!eregi("^[_\.0-9a-z-]+@([0-9a-z][-0-9a-z\.]+)\.([a-z]{2,3}$)", $email, $check)) { 
	$context_error[] = "Your email address does not appear to be in a correct format."; 
} 

if (count($context_error)) 
	$context = "There was a problem processing your information.  The specific problem(s) are listed below.";

/******************************************
if ($do_debug == "yes") {
echo "email " . $email ." check " . $check[1] . "<br>";
echo "here 0 " . $check[0] . "<br>" ;
echo "here 1 " . $check[1] . "<br>" ;
echo "here 2 " . $check[2] . "<br>" ;
echo "context " . $context_error[0];
}
******************************************/

/******************************************
 ERROR CHECK THE SUBJECT (CATEGORY)
******************************************/

if (empty($cat_id)) {
	$context_error[] = "Please choose a subject for your email.";
}


/******************************************
 ERROR CHECK THE COMMENTS (COMMENT)
******************************************/

if (trim(empty($comment))) {
	$context_error[] = "Please enter comments for your email.";
} else {
    $comment = fixQuotes($comment);
}


/******************************************
 ERROR CHECK IS COMPLETE.  IF THERE ARE NO
 ERRORS, THEN PROCEED WITH THE INSERT.  OTHERWISE
 DROP THE $CONTEXT AND $CONTEXT_ERRORS.
******************************************/

if ($context_error) {
	$error_count = count($context_error);
	include($page_template);

	return;
}


/******************************************
 INSERT THE INFORMATION INTO THE FEEDBACK TABLE
 BEFORE INSERTING, MAKE SURE THERE ISN'T ALREADY
 A RECORD PRESENT (DOUBLE-CLICK, BACK BUTTON, ETC.).
 IF THERE IS, UPDATE THAT RECORD INSTEAD.
******************************************/

	$chk_query = "SELECT FEEDBACK_ID " .
						 	 "FROM FEEDBACK WHERE FEEDBACK_ID = '$feedback_id'" ;

	$chk_result = pg_exec($conn,$chk_query);
  $chk_numrows = pg_numrows($chk_result);

if (!$chk_numrows) {

	$ins_query = "INSERT INTO FEEDBACK ( " .
		  				 "FEEDBACK_ID, CAT_ID, EMAIL, COMMENT, SENT_DATE) " .
							 "VALUES ('$feedback_id',$cat_id,'$email'," . sqlText($comment) . ",now())";

	$ins_result = pg_exec($conn,$ins_query);					
}
else {

	$upd_query = "UPDATE FEEDBACK SET " .
							 "CAT_ID = $cat_id, " .
							 "EMAIL = '$email', " .
							 "COMMENT = " . sqlText($comment) . " " .
							 "WHERE FEEDBACK_ID = '$feedback_id'";

	$upd_result = pg_exec($conn,$upd_query);	  
}

/******************************************
 GET THE RECIPIENT(S) TO RECEIVE THE EMAIL,
 DEFAULT IS WEBMASTER
******************************************/
	$em_query = "SELECT A.EMAIL, C.CAT_NAME FROM STAFF A, STAFF_EMAIL B, CATEGORY C " .
						"WHERE B.CAT_ID = $cat_id " .
						"AND C.CAT_ID = $cat_id " .
						"AND A.STAFF_ID = B.STAFF_ID " .
						"AND C.GROUP_ID = $site_group_id ";
	
	$em_result = pg_exec($conn,$em_query);

	
	$r = 0;
	
	while ($row = @pg_fetch_array($em_result,$r++)) {
		$em_to[$row["email"]] = $row["email"];
		list($to_key,$to_value) = each($em_to);
		
		if ($r == 1) {
		$em_subj[$row["subj"]] = $row["cat_name"];
		list($subj_key,$subj_value) = each($em_subj);
		}
	
/******************************************
 INSERT THE MAIL CLASS HERE.  NOT SURE IF
 WE ARE GOING TO USE THE SMTP SERVER, OR
 LOCAL MAIL.  ONCE THIS IS RESOLVED, PUT IT
 HERE
 
*******************************************/
		if ($do_debug == "yes") {
			echo "Mail to: " . $to_value . "<br>";
			echo "From: " . $email . "<br>";
			echo "Subj: " . $subj_value . "<br>";
			echo "Text: " . $comment . "<p>";
		}
		mail("$to_value","Message from website regarding $subj_value",wordwrap($comment, 70),"From:$email");
	}		 
			 
/******************************************
EVERYTHING IS FINISHED SO INCLUDE THE TEMPLATE
******************************************/
		$context = "Thank you for your comments.  We will respond to your e-mail as quickly as possible.";
    include($page_template);
 ?>
